from setuptools import setup

setup(name='rtml_distributions',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['rtml_distributions'],
      author='Rodolfo Teles',
      author_email='rodolfojeronimoteles@gmail.com',
      zip_safe=False)
